"use strict";
// Copyright (c) Jupyter Development Team.
// Distributed under the terms of the Modified BSD License.
Object.defineProperty(exports, "__esModule", { value: true });
const services_1 = require("@jupyterlab/services");
/**
 * Make a client-side request to the GitHub API.
 *
 * @param url - the api path for the GitHub API v3
 *   (not including the base url).
 *
 * @returns a Promise resolved with the JSON response.
 */
function browserApiRequest(url) {
    return window.fetch(url).then(response => {
        if (response.status !== 200) {
            return response.json().then(data => {
                throw new services_1.ServerConnection.ResponseError(response, data.message);
            });
        }
        return response.json();
    });
}
exports.browserApiRequest = browserApiRequest;
/**
 * Make a request to the notebook server proxy for the
 * GitHub API.
 *
 * @param url - the api path for the GitHub API v3
 *   (not including the base url)
 *
 * @param settings - the settings for the current notebook server.
 *
 * @returns a Promise resolved with the JSON response.
 */
function proxiedApiRequest(url, settings) {
    return services_1.ServerConnection.makeRequest(url, {}, settings).then(response => {
        if (response.status !== 200) {
            return response.json().then(data => {
                throw new services_1.ServerConnection.ResponseError(response, data.message);
            });
        }
        return response.json();
    });
}
exports.proxiedApiRequest = proxiedApiRequest;
/**
 * Typings representing contents from the GitHub API v3.
 * Cf: https://developer.github.com/v3/repos/contents/
 */
class GitHubContents {
}
exports.GitHubContents = GitHubContents;
/**
 * Typings representing file contents from the GitHub API v3.
 * Cf: https://developer.github.com/v3/repos/contents/#response-if-content-is-a-file
 */
class GitHubFileContents extends GitHubContents {
}
exports.GitHubFileContents = GitHubFileContents;
/**
 * Typings representing a directory from the GitHub API v3.
 */
class GitHubDirectoryContents extends GitHubContents {
}
exports.GitHubDirectoryContents = GitHubDirectoryContents;
/**
 * Typings representing a blob from the GitHub API v3.
 * Cf: https://developer.github.com/v3/git/blobs/#response
 */
class GitHubBlob {
}
exports.GitHubBlob = GitHubBlob;
/**
 * Typings representing symlink contents from the GitHub API v3.
 * Cf: https://developer.github.com/v3/repos/contents/#response-if-content-is-a-symlink
 */
class GitHubSymlinkContents extends GitHubContents {
}
exports.GitHubSymlinkContents = GitHubSymlinkContents;
/**
 * Typings representing submodule contents from the GitHub API v3.
 * Cf: https://developer.github.com/v3/repos/contents/#response-if-content-is-a-submodule
 */
class GitHubSubmoduleContents extends GitHubContents {
}
exports.GitHubSubmoduleContents = GitHubSubmoduleContents;
/**
 * Typings representing repositories from the GitHub API v3.
 * Cf: https://developer.github.com/v3/repos/#list-organization-repositories
 *
 * #### Notes
 *   This is incomplete.
 */
class GitHubRepo {
}
exports.GitHubRepo = GitHubRepo;
